summaryrefslogtreecommitdiffstats
path: root/examples/h5_elink_unix2win.c
diff options
context:
space:
mode:
Diffstat (limited to 'examples/h5_elink_unix2win.c')
-rw-r--r--examples/h5_elink_unix2win.c6
1 files changed, 3 insertions, 3 deletions
diff --git a/examples/h5_elink_unix2win.c b/examples/h5_elink_unix2win.c
index 35ab271..b354661 100644
--- a/examples/h5_elink_unix2win.c
+++ b/examples/h5_elink_unix2win.c
@@ -118,9 +118,9 @@ error:
return -1;
}
-const H5L_link_class_t elink_unix2win_class[1] = {{
- H5L_LINK_CLASS_T_VERS, /* H5L_link_class_t version */
- H5L_LINK_EXTERNAL, /* Link type id number */
+const H5L_class_t elink_unix2win_class[1] = {{
+ H5L_LINK_CLASS_T_VERS, /* H5L_class_t version */
+ H5L_TYPE_EXTERNAL, /* Link type id number */
"unix2win external link", /* Link class name for debugging */
NULL, /* Creation callback */
NULL, /* Move callback */